import React, { useRef, useEffect, useState } from 'react';
import { Basemap } from './Basemap';
const { Map, View } = ol;

const mapZoom = {
  zoom: 1.9068905956085187,
  center: [831533.7387061372, 1156963.888662201]
};

export const Cartography = () => {
  const ref = useRef(null);
  const [mapAndView, setMapAndView] = useState();

  useEffect(() => {
    const { zoom, center } = mapZoom;

    const view = new View({ center, zoom });
    const map = new Map({
      target: ref.current,
      layers: [Basemap],
      view
    });

    setMapAndView({ map, view });
    // Free up map resources when destroying the component.
    // Draws from https://stackoverflow.com/questions/25995334/deconstructing-an-open-layers-3-map
    return () => {
      map.setTarget(null);
    };
  }, []);

  useEffect(() => {
    if (!mapAndView) return;
    const { map, view } = mapAndView;
    const listener = event => {
      const zoom = view.getZoom();
      const center = view.getCenter();
      console.log(JSON.stringify({ zoom, center }));
    };
    map.on('moveend', listener);
    return () => {
      map.un('moveend', listener);
    };
  }, [mapAndView]);

  return <div style={{ flex: 1 }} ref={ref} />;
};
